##############################
ConversionPartLoad class
##############################

.. |br| raw:: html

   <br />

ConversionPartLoad components are Conversion components that are additionally able to capture part-load behaviour.
For that, the module is using piecewise linear functions and special ordered sets (SOS) constraints.

**ConversionPartLoad class description:**

.. automodule:: conversionPartLoad
.. autoclass:: ConversionPartLoad
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: ConversionPartLoad
   :parts: 1

|

**ConversionPartLoadModel class description:**

.. autoclass:: ConversionPartLoadModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: ConversionPartLoadModel
   :parts: 1

